#include <gforth/0.7.9_20150820/libcc.h>
#include <X11/X.h>
#include <X11/Xlib.h>
#include <X11/Xutil.h>
ptrpair libgfx_LTX_gforth_c___struct__XExtData__ptr___free_private_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  Cell ptr = *sp++;
  sp[0]=((struct _XExtData*)ptr)->free_private((void *)(sp[0]));
  x.sp = sp+0;
  return x;
}
ptrpair libgfx_LTX_gforth_c___struct_funcs__ptr___create_image_aaunnauunn_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=9, farg0=-1;
  Cell ptr = *sp++;
  sp[9]=(Cell)((struct funcs*)ptr)->create_image((void *)(sp[9]),(void *)(sp[8]),sp[7],sp[6],sp[5],(void *)(sp[4]),sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+9;
  return x;
}
ptrpair libgfx_LTX_gforth_c___struct_funcs__ptr___destroy_image_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  Cell ptr = *sp++;
  sp[0]=((struct funcs*)ptr)->destroy_image((void *)(sp[0]));
  x.sp = sp+0;
  return x;
}
ptrpair libgfx_LTX_gforth_c___struct_funcs__ptr___get_pixel_ann_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  Cell ptr = *sp++;
  sp[2]=((struct funcs*)ptr)->get_pixel((void *)(sp[2]),sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c___struct_funcs__ptr___put_pixel_annu_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  Cell ptr = *sp++;
  sp[3]=((struct funcs*)ptr)->put_pixel((void *)(sp[3]),sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c___struct_funcs__ptr___sub_image_annuu_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  Cell ptr = *sp++;
  sp[4]=(Cell)((struct funcs*)ptr)->sub_image((void *)(sp[4]),sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfx_LTX_gforth_c___struct_funcs__ptr___add_pixel_an_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  Cell ptr = *sp++;
  sp[1]=((struct funcs*)ptr)->add_pixel((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
#define CALLBACK_XIMProc_(I) \
void libgfx_LTX_gforth_cb_XIMProc__##I (void* x0, void* x1, void* x2) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(Cell)(x0); \
  sp[-2]=(Cell)(x1); \
  sp[-3]=(Cell)(x2); \
  sp+=-3; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfx_LTX_gforth_cbips_XIMProc_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
; \
}
Xt* libgfx_LTX_gforth_cbips_XIMProc_[2] = {
  0, 0,};
CALLBACK_XIMProc_(0)
CALLBACK_XIMProc_(1)
const Address libgfx_LTX_gforth_callbacks_XIMProc_[2] = {
  (Address)libgfx_LTX_gforth_cb_XIMProc__0,
  (Address)libgfx_LTX_gforth_cb_XIMProc__1,
};
#define CALLBACK_XICProc_(I) \
Cell libgfx_LTX_gforth_cb_XICProc__##I (void* x0, void* x1, void* x2) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(Cell)(x0); \
  sp[-2]=(Cell)(x1); \
  sp[-3]=(Cell)(x2); \
  sp+=-3; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfx_LTX_gforth_cbips_XICProc_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfx_LTX_gforth_cbips_XICProc_[2] = {
  0, 0,};
CALLBACK_XICProc_(0)
CALLBACK_XICProc_(1)
const Address libgfx_LTX_gforth_callbacks_XICProc_[2] = {
  (Address)libgfx_LTX_gforth_cb_XICProc__0,
  (Address)libgfx_LTX_gforth_cb_XICProc__1,
};
#define CALLBACK_XIDProc_(I) \
void libgfx_LTX_gforth_cb_XIDProc__##I (void* x0, void* x1, void* x2) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(Cell)(x0); \
  sp[-2]=(Cell)(x1); \
  sp[-3]=(Cell)(x2); \
  sp+=-3; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfx_LTX_gforth_cbips_XIDProc_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
; \
}
Xt* libgfx_LTX_gforth_cbips_XIDProc_[2] = {
  0, 0,};
CALLBACK_XIDProc_(0)
CALLBACK_XIDProc_(1)
const Address libgfx_LTX_gforth_callbacks_XIDProc_[2] = {
  (Address)libgfx_LTX_gforth_cb_XIDProc__0,
  (Address)libgfx_LTX_gforth_cb_XIDProc__1,
};
#define CALLBACK_XErrorHandler_(I) \
Cell libgfx_LTX_gforth_cb_XErrorHandler__##I (void* x0, void* x1) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(Cell)(x0); \
  sp[-2]=(Cell)(x1); \
  sp+=-2; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfx_LTX_gforth_cbips_XErrorHandler_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfx_LTX_gforth_cbips_XErrorHandler_[2] = {
  0, 0,};
CALLBACK_XErrorHandler_(0)
CALLBACK_XErrorHandler_(1)
const Address libgfx_LTX_gforth_callbacks_XErrorHandler_[2] = {
  (Address)libgfx_LTX_gforth_cb_XErrorHandler__0,
  (Address)libgfx_LTX_gforth_cb_XErrorHandler__1,
};
#define CALLBACK_XIOErrorHandler_(I) \
Cell libgfx_LTX_gforth_cb_XIOErrorHandler__##I (void* x0) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(Cell)(x0); \
  sp+=-1; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfx_LTX_gforth_cbips_XIOErrorHandler_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfx_LTX_gforth_cbips_XIOErrorHandler_[2] = {
  0, 0,};
CALLBACK_XIOErrorHandler_(0)
CALLBACK_XIOErrorHandler_(1)
const Address libgfx_LTX_gforth_callbacks_XIOErrorHandler_[2] = {
  (Address)libgfx_LTX_gforth_cb_XIOErrorHandler__0,
  (Address)libgfx_LTX_gforth_cb_XIOErrorHandler__1,
};
#define CALLBACK_XConnectionWatchProc_(I) \
void libgfx_LTX_gforth_cb_XConnectionWatchProc__##I (void* x0, void* x1, Cell x2, Cell x3, void* x4) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(Cell)(x0); \
  sp[-2]=(Cell)(x1); \
  sp[-3]=(x2); \
  sp[-4]=(x3); \
  sp[-5]=(Cell)(x4); \
  sp+=-5; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfx_LTX_gforth_cbips_XConnectionWatchProc_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
; \
}
Xt* libgfx_LTX_gforth_cbips_XConnectionWatchProc_[2] = {
  0, 0,};
CALLBACK_XConnectionWatchProc_(0)
CALLBACK_XConnectionWatchProc_(1)
const Address libgfx_LTX_gforth_callbacks_XConnectionWatchProc_[2] = {
  (Address)libgfx_LTX_gforth_cb_XConnectionWatchProc__0,
  (Address)libgfx_LTX_gforth_cb_XConnectionWatchProc__1,
};
ptrpair libgfx_LTX_gforth_c__Xmblen_an_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=_Xmblen((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XLoadQueryFont_aa_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=(Cell)XLoadQueryFont((void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XQueryFont_au_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=(Cell)XQueryFont((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XGetMotionEvents_auuua_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  sp[4]=(Cell)XGetMotionEvents((void *)(sp[4]),sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XDeleteModifiermapEntry_ann_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=(Cell)XDeleteModifiermapEntry((void *)(sp[2]),sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XGetModifierMapping_a_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=(Cell)XGetModifierMapping((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XInsertModifiermapEntry_ann_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=(Cell)XInsertModifiermapEntry((void *)(sp[2]),sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XNewModifiermap_n_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=(Cell)XNewModifiermap(sp[0]);
  return x;
}
ptrpair libgfx_LTX_gforth_c_XCreateImage_aaunnauunn_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=9, farg0=-1;
  sp[9]=(Cell)XCreateImage((void *)(sp[9]),(void *)(sp[8]),sp[7],sp[6],sp[5],(void *)(sp[4]),sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+9;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XInitImage_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XInitImage((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XGetImage_aunnuuun_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=7, farg0=-1;
  sp[7]=(Cell)XGetImage((void *)(sp[7]),sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+7;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XGetSubImage_aunnuuunann_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=10, farg0=-1;
  sp[10]=(Cell)XGetSubImage((void *)(sp[10]),sp[9],sp[8],sp[7],sp[6],sp[5],sp[4],sp[3],(void *)(sp[2]),sp[1],sp[0]);
  x.sp = sp+10;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XOpenDisplay_a_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=(Cell)XOpenDisplay((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XrmInitialize__v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  XrmInitialize();
  return x;
}
ptrpair libgfx_LTX_gforth_c_XFetchBytes_aa_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=(Cell)XFetchBytes((void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XFetchBuffer_aan_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=(Cell)XFetchBuffer((void *)(sp[2]),(void *)(sp[1]),sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XGetAtomName_au_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=(Cell)XGetAtomName((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XGetAtomNames_aana_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=XGetAtomNames((void *)(sp[3]),(void *)(sp[2]),sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XGetDefault_aaa_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=(Cell)XGetDefault((void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XDisplayName_a_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=(Cell)XDisplayName((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XKeysymToString_u_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=(Cell)XKeysymToString(sp[0]);
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSynchronize_an_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=(Cell)XSynchronize((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetAfterFunction_aa_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=(Cell)XSetAfterFunction((void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XInternAtom_aan_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XInternAtom((void *)(sp[2]),(void *)(sp[1]),sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XInternAtoms_aanna_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  sp[4]=XInternAtoms((void *)(sp[4]),(void *)(sp[3]),sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XCopyColormapAndFree_au_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XCopyColormapAndFree((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XCreateColormap_auan_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=XCreateColormap((void *)(sp[3]),sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XCreatePixmapCursor_auuaauu_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=6, farg0=-1;
  sp[6]=XCreatePixmapCursor((void *)(sp[6]),sp[5],sp[4],(void *)(sp[3]),(void *)(sp[2]),sp[1],sp[0]);
  x.sp = sp+6;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XCreateGlyphCursor_auuuuaa_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=6, farg0=-1;
  sp[6]=XCreateGlyphCursor((void *)(sp[6]),sp[5],sp[4],sp[3],sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+6;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XCreateFontCursor_au_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XCreateFontCursor((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XLoadFont_aa_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XLoadFont((void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XCreateGC_auua_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=(Cell)XCreateGC((void *)(sp[3]),sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XGContextFromGC_a_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XGContextFromGC((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XFlushGC_aa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  XFlushGC((void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XCreatePixmap_auuuu_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  sp[4]=XCreatePixmap((void *)(sp[4]),sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XCreateBitmapFromData_auauu_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  sp[4]=XCreateBitmapFromData((void *)(sp[4]),sp[3],(void *)(sp[2]),sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XCreatePixmapFromBitmapData_auauuuuu_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=7, farg0=-1;
  sp[7]=XCreatePixmapFromBitmapData((void *)(sp[7]),sp[6],(void *)(sp[5]),sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+7;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XCreateSimpleWindow_aunnuuuuu_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=8, farg0=-1;
  sp[8]=XCreateSimpleWindow((void *)(sp[8]),sp[7],sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+8;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XGetSelectionOwner_au_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XGetSelectionOwner((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XCreateWindow_aunnuuunuaua_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=11, farg0=-1;
  sp[11]=XCreateWindow((void *)(sp[11]),sp[10],sp[9],sp[8],sp[7],sp[6],sp[5],sp[4],sp[3],(void *)(sp[2]),sp[1],(void *)(sp[0]));
  x.sp = sp+11;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XListInstalledColormaps_aua_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=(Cell)XListInstalledColormaps((void *)(sp[2]),sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XListFonts_aana_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=(Cell)XListFonts((void *)(sp[3]),(void *)(sp[2]),sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XListFontsWithInfo_aanaa_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  sp[4]=(Cell)XListFontsWithInfo((void *)(sp[4]),(void *)(sp[3]),sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XGetFontPath_aa_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=(Cell)XGetFontPath((void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XListExtensions_aa_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=(Cell)XListExtensions((void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XListProperties_aua_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=(Cell)XListProperties((void *)(sp[2]),sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XListHosts_aaa_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=(Cell)XListHosts((void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XKeycodeToKeysym_ann_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XKeycodeToKeysym((void *)(sp[2]),sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XLookupKeysym_an_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XLookupKeysym((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XGetKeyboardMapping_anna_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=(Cell)XGetKeyboardMapping((void *)(sp[3]),sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XStringToKeysym_a_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XStringToKeysym((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XMaxRequestSize_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XMaxRequestSize((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XExtendedMaxRequestSize_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XExtendedMaxRequestSize((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XResourceManagerString_a_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=(Cell)XResourceManagerString((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XScreenResourceString_a_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=(Cell)XScreenResourceString((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XDisplayMotionBufferSize_a_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XDisplayMotionBufferSize((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XVisualIDFromVisual_a_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XVisualIDFromVisual((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XInitThreads__n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  sp[-1]=XInitThreads();
  x.sp = sp+-1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XLockDisplay_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  XLockDisplay((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XUnlockDisplay_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  XUnlockDisplay((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XInitExtension_aa_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=(Cell)XInitExtension((void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XAddExtension_a_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=(Cell)XAddExtension((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XFindOnExtensionList_an_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=(Cell)XFindOnExtensionList((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XEHeadOfExtensionList_a_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=(Cell)XEHeadOfExtensionList(*(XEDataObject*)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XRootWindow_an_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XRootWindow((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XDefaultRootWindow_a_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XDefaultRootWindow((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XRootWindowOfScreen_a_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XRootWindowOfScreen((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XDefaultVisual_an_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=(Cell)XDefaultVisual((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XDefaultVisualOfScreen_a_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=(Cell)XDefaultVisualOfScreen((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XDefaultGC_an_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=(Cell)XDefaultGC((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XDefaultGCOfScreen_a_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=(Cell)XDefaultGCOfScreen((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XBlackPixel_an_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XBlackPixel((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XWhitePixel_an_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XWhitePixel((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XAllPlanes__u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  sp[-1]=XAllPlanes();
  x.sp = sp+-1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XBlackPixelOfScreen_a_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XBlackPixelOfScreen((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XWhitePixelOfScreen_a_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XWhitePixelOfScreen((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XNextRequest_a_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XNextRequest((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XLastKnownRequestProcessed_a_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XLastKnownRequestProcessed((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XServerVendor_a_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=(Cell)XServerVendor((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XDisplayString_a_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=(Cell)XDisplayString((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XDefaultColormap_an_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XDefaultColormap((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XDefaultColormapOfScreen_a_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XDefaultColormapOfScreen((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XDisplayOfScreen_a_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=(Cell)XDisplayOfScreen((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XScreenOfDisplay_an_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=(Cell)XScreenOfDisplay((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XDefaultScreenOfDisplay_a_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=(Cell)XDefaultScreenOfDisplay((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XEventMaskOfScreen_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XEventMaskOfScreen((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XScreenNumberOfScreen_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XScreenNumberOfScreen((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetErrorHandler_a_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=(Cell)XSetErrorHandler((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetIOErrorHandler_a_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=(Cell)XSetIOErrorHandler((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XListPixmapFormats_aa_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=(Cell)XListPixmapFormats((void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XListDepths_ana_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=(Cell)XListDepths((void *)(sp[2]),sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XReconfigureWMWindow_aunua_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  sp[4]=XReconfigureWMWindow((void *)(sp[4]),sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XGetWMProtocols_auaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=XGetWMProtocols((void *)(sp[3]),sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetWMProtocols_auan_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=XSetWMProtocols((void *)(sp[3]),sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XIconifyWindow_aun_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XIconifyWindow((void *)(sp[2]),sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XWithdrawWindow_aun_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XWithdrawWindow((void *)(sp[2]),sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XGetCommand_auaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=XGetCommand((void *)(sp[3]),sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XGetWMColormapWindows_auaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=XGetWMColormapWindows((void *)(sp[3]),sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetWMColormapWindows_auan_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=XSetWMColormapWindows((void *)(sp[3]),sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XFreeStringList_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  XFreeStringList((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetTransientForHint_auu_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XSetTransientForHint((void *)(sp[2]),sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XActivateScreenSaver_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XActivateScreenSaver((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XAddHost_aa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XAddHost((void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XAddHosts_aan_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XAddHosts((void *)(sp[2]),(void *)(sp[1]),sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XAddToExtensionList_aa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XAddToExtensionList((void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XAddToSaveSet_au_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XAddToSaveSet((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XAllocColor_aua_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XAllocColor((void *)(sp[2]),sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XAllocColorCells_aunauau_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=6, farg0=-1;
  sp[6]=XAllocColorCells((void *)(sp[6]),sp[5],sp[4],(void *)(sp[3]),sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+6;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XAllocColorPlanes_aunannnnaaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=10, farg0=-1;
  sp[10]=XAllocColorPlanes((void *)(sp[10]),sp[9],sp[8],(void *)(sp[7]),sp[6],sp[5],sp[4],sp[3],(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+10;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XAllocNamedColor_auaaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  sp[4]=XAllocNamedColor((void *)(sp[4]),sp[3],(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XAllowEvents_anu_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XAllowEvents((void *)(sp[2]),sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XAutoRepeatOff_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XAutoRepeatOff((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XAutoRepeatOn_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XAutoRepeatOn((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XBell_an_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XBell((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XBitmapBitOrder_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XBitmapBitOrder((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XBitmapPad_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XBitmapPad((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XBitmapUnit_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XBitmapUnit((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XCellsOfScreen_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XCellsOfScreen((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XChangeActivePointerGrab_auuu_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=XChangeActivePointerGrab((void *)(sp[3]),sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XChangeGC_aaua_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=XChangeGC((void *)(sp[3]),(void *)(sp[2]),sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XChangeKeyboardControl_aua_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XChangeKeyboardControl((void *)(sp[2]),sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XChangeKeyboardMapping_annan_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  sp[4]=XChangeKeyboardMapping((void *)(sp[4]),sp[3],sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XChangePointerControl_annnnn_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  sp[5]=XChangePointerControl((void *)(sp[5]),sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XChangeProperty_auuunnan_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=7, farg0=-1;
  sp[7]=XChangeProperty((void *)(sp[7]),sp[6],sp[5],sp[4],sp[3],sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+7;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XChangeSaveSet_aun_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XChangeSaveSet((void *)(sp[2]),sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XChangeWindowAttributes_auua_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=XChangeWindowAttributes((void *)(sp[3]),sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XCheckIfEvent_aaaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=XCheckIfEvent((void *)(sp[3]),(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XCheckMaskEvent_ana_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XCheckMaskEvent((void *)(sp[2]),sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XCheckTypedEvent_ana_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XCheckTypedEvent((void *)(sp[2]),sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XCheckTypedWindowEvent_auna_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=XCheckTypedWindowEvent((void *)(sp[3]),sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XCheckWindowEvent_auna_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=XCheckWindowEvent((void *)(sp[3]),sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XCirculateSubwindows_aun_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XCirculateSubwindows((void *)(sp[2]),sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XCirculateSubwindowsDown_au_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XCirculateSubwindowsDown((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XCirculateSubwindowsUp_au_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XCirculateSubwindowsUp((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XClearArea_aunnuun_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=6, farg0=-1;
  sp[6]=XClearArea((void *)(sp[6]),sp[5],sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+6;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XClearWindow_au_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XClearWindow((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XCloseDisplay_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XCloseDisplay((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XConfigureWindow_auua_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=XConfigureWindow((void *)(sp[3]),sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XConnectionNumber_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XConnectionNumber((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XConvertSelection_auuuuu_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  sp[5]=XConvertSelection((void *)(sp[5]),sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XCopyArea_auuannuunn_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=9, farg0=-1;
  sp[9]=XCopyArea((void *)(sp[9]),sp[8],sp[7],(void *)(sp[6]),sp[5],sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+9;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XCopyGC_aaua_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=XCopyGC((void *)(sp[3]),(void *)(sp[2]),sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XCopyPlane_auuannuunnu_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=10, farg0=-1;
  sp[10]=XCopyPlane((void *)(sp[10]),sp[9],sp[8],(void *)(sp[7]),sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+10;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XDefaultDepth_an_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XDefaultDepth((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XDefaultDepthOfScreen_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XDefaultDepthOfScreen((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XDefaultScreen_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XDefaultScreen((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XDefineCursor_auu_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XDefineCursor((void *)(sp[2]),sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XDeleteProperty_auu_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XDeleteProperty((void *)(sp[2]),sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XDestroyWindow_au_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XDestroyWindow((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XDestroySubwindows_au_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XDestroySubwindows((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XDoesBackingStore_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XDoesBackingStore((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XDoesSaveUnders_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XDoesSaveUnders((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XDisableAccessControl_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XDisableAccessControl((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XDisplayCells_an_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XDisplayCells((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XDisplayHeight_an_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XDisplayHeight((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XDisplayHeightMM_an_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XDisplayHeightMM((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XDisplayKeycodes_aaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XDisplayKeycodes((void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XDisplayPlanes_an_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XDisplayPlanes((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XDisplayWidth_an_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XDisplayWidth((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XDisplayWidthMM_an_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XDisplayWidthMM((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XDrawArc_auannuunn_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=8, farg0=-1;
  sp[8]=XDrawArc((void *)(sp[8]),sp[7],(void *)(sp[6]),sp[5],sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+8;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XDrawArcs_auaan_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  sp[4]=XDrawArcs((void *)(sp[4]),sp[3],(void *)(sp[2]),(void *)(sp[1]),sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XDrawImageString_auannan_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=6, farg0=-1;
  sp[6]=XDrawImageString((void *)(sp[6]),sp[5],(void *)(sp[4]),sp[3],sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+6;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XDrawImageString16_auannan_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=6, farg0=-1;
  sp[6]=XDrawImageString16((void *)(sp[6]),sp[5],(void *)(sp[4]),sp[3],sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+6;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XDrawLine_auannnn_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=6, farg0=-1;
  sp[6]=XDrawLine((void *)(sp[6]),sp[5],(void *)(sp[4]),sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+6;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XDrawLines_auaann_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  sp[5]=XDrawLines((void *)(sp[5]),sp[4],(void *)(sp[3]),(void *)(sp[2]),sp[1],sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XDrawPoint_auann_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  sp[4]=XDrawPoint((void *)(sp[4]),sp[3],(void *)(sp[2]),sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XDrawPoints_auaann_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  sp[5]=XDrawPoints((void *)(sp[5]),sp[4],(void *)(sp[3]),(void *)(sp[2]),sp[1],sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XDrawRectangle_auannuu_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=6, farg0=-1;
  sp[6]=XDrawRectangle((void *)(sp[6]),sp[5],(void *)(sp[4]),sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+6;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XDrawRectangles_auaan_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  sp[4]=XDrawRectangles((void *)(sp[4]),sp[3],(void *)(sp[2]),(void *)(sp[1]),sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XDrawSegments_auaan_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  sp[4]=XDrawSegments((void *)(sp[4]),sp[3],(void *)(sp[2]),(void *)(sp[1]),sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XDrawString_auannan_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=6, farg0=-1;
  sp[6]=XDrawString((void *)(sp[6]),sp[5],(void *)(sp[4]),sp[3],sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+6;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XDrawString16_auannan_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=6, farg0=-1;
  sp[6]=XDrawString16((void *)(sp[6]),sp[5],(void *)(sp[4]),sp[3],sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+6;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XDrawText_auannan_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=6, farg0=-1;
  sp[6]=XDrawText((void *)(sp[6]),sp[5],(void *)(sp[4]),sp[3],sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+6;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XDrawText16_auannan_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=6, farg0=-1;
  sp[6]=XDrawText16((void *)(sp[6]),sp[5],(void *)(sp[4]),sp[3],sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+6;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XEnableAccessControl_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XEnableAccessControl((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XEventsQueued_an_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XEventsQueued((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XFetchName_aua_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XFetchName((void *)(sp[2]),sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XFillArc_auannuunn_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=8, farg0=-1;
  sp[8]=XFillArc((void *)(sp[8]),sp[7],(void *)(sp[6]),sp[5],sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+8;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XFillArcs_auaan_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  sp[4]=XFillArcs((void *)(sp[4]),sp[3],(void *)(sp[2]),(void *)(sp[1]),sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XFillPolygon_auaannn_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=6, farg0=-1;
  sp[6]=XFillPolygon((void *)(sp[6]),sp[5],(void *)(sp[4]),(void *)(sp[3]),sp[2],sp[1],sp[0]);
  x.sp = sp+6;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XFillRectangle_auannuu_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=6, farg0=-1;
  sp[6]=XFillRectangle((void *)(sp[6]),sp[5],(void *)(sp[4]),sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+6;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XFillRectangles_auaan_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  sp[4]=XFillRectangles((void *)(sp[4]),sp[3],(void *)(sp[2]),(void *)(sp[1]),sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XFlush_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XFlush((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XForceScreenSaver_an_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XForceScreenSaver((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XFree_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XFree((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XFreeColormap_au_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XFreeColormap((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XFreeColors_auanu_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  sp[4]=XFreeColors((void *)(sp[4]),sp[3],(void *)(sp[2]),sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XFreeCursor_au_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XFreeCursor((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XFreeExtensionList_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XFreeExtensionList((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XFreeFont_aa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XFreeFont((void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XFreeFontInfo_aan_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XFreeFontInfo((void *)(sp[2]),(void *)(sp[1]),sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XFreeFontNames_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XFreeFontNames((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XFreeFontPath_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XFreeFontPath((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XFreeGC_aa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XFreeGC((void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XFreeModifiermap_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XFreeModifiermap((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XFreePixmap_au_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XFreePixmap((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XGeometry_anaauuunnaaaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=12, farg0=-1;
  sp[12]=XGeometry((void *)(sp[12]),sp[11],(void *)(sp[10]),(void *)(sp[9]),sp[8],sp[7],sp[6],sp[5],sp[4],(void *)(sp[3]),(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+12;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XGetErrorDatabaseText_aaaaan_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  sp[5]=XGetErrorDatabaseText((void *)(sp[5]),(void *)(sp[4]),(void *)(sp[3]),(void *)(sp[2]),(void *)(sp[1]),sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XGetErrorText_anan_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=XGetErrorText((void *)(sp[3]),sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XGetFontProperty_aua_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XGetFontProperty((void *)(sp[2]),sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XGetGCValues_aaua_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=XGetGCValues((void *)(sp[3]),(void *)(sp[2]),sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XGetGeometry_auaaaaaaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=8, farg0=-1;
  sp[8]=XGetGeometry((void *)(sp[8]),sp[7],(void *)(sp[6]),(void *)(sp[5]),(void *)(sp[4]),(void *)(sp[3]),(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+8;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XGetIconName_aua_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XGetIconName((void *)(sp[2]),sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XGetInputFocus_aaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XGetInputFocus((void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XGetKeyboardControl_aa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XGetKeyboardControl((void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XGetPointerControl_aaaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=XGetPointerControl((void *)(sp[3]),(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XGetPointerMapping_aan_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XGetPointerMapping((void *)(sp[2]),(void *)(sp[1]),sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XGetScreenSaver_aaaaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  sp[4]=XGetScreenSaver((void *)(sp[4]),(void *)(sp[3]),(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XGetTransientForHint_aua_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XGetTransientForHint((void *)(sp[2]),sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XGetWindowProperty_auunnnuaaaaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=11, farg0=-1;
  sp[11]=XGetWindowProperty((void *)(sp[11]),sp[10],sp[9],sp[8],sp[7],sp[6],sp[5],(void *)(sp[4]),(void *)(sp[3]),(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+11;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XGetWindowAttributes_aua_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XGetWindowAttributes((void *)(sp[2]),sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XGrabButton_auuununnuu_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=9, farg0=-1;
  sp[9]=XGrabButton((void *)(sp[9]),sp[8],sp[7],sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+9;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XGrabKey_anuunnn_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=6, farg0=-1;
  sp[6]=XGrabKey((void *)(sp[6]),sp[5],sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+6;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XGrabKeyboard_aunnnu_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  sp[5]=XGrabKeyboard((void *)(sp[5]),sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XGrabPointer_aununnuuu_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=8, farg0=-1;
  sp[8]=XGrabPointer((void *)(sp[8]),sp[7],sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+8;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XGrabServer_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XGrabServer((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XHeightMMOfScreen_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XHeightMMOfScreen((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XHeightOfScreen_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XHeightOfScreen((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XIfEvent_aaaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=XIfEvent((void *)(sp[3]),(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XImageByteOrder_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XImageByteOrder((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XInstallColormap_au_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XInstallColormap((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XKeysymToKeycode_au_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XKeysymToKeycode((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XKillClient_au_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XKillClient((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XLookupColor_auaaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  sp[4]=XLookupColor((void *)(sp[4]),sp[3],(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XLowerWindow_au_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XLowerWindow((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XMapRaised_au_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XMapRaised((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XMapSubwindows_au_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XMapSubwindows((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XMapWindow_au_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XMapWindow((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XMaskEvent_ana_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XMaskEvent((void *)(sp[2]),sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XMaxCmapsOfScreen_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XMaxCmapsOfScreen((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XMinCmapsOfScreen_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XMinCmapsOfScreen((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XMoveResizeWindow_aunnuu_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  sp[5]=XMoveResizeWindow((void *)(sp[5]),sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XMoveWindow_aunn_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=XMoveWindow((void *)(sp[3]),sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XNextEvent_aa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XNextEvent((void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XNoOp_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XNoOp((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XParseColor_auaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=XParseColor((void *)(sp[3]),sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XParseGeometry_aaaaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  sp[4]=XParseGeometry((void *)(sp[4]),(void *)(sp[3]),(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XPeekEvent_aa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XPeekEvent((void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XPeekIfEvent_aaaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=XPeekIfEvent((void *)(sp[3]),(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XPending_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XPending((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XPlanesOfScreen_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XPlanesOfScreen((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XProtocolRevision_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XProtocolRevision((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XProtocolVersion_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XProtocolVersion((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XPutBackEvent_aa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XPutBackEvent((void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XPutImage_auaannnnuu_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=9, farg0=-1;
  sp[9]=XPutImage((void *)(sp[9]),sp[8],(void *)(sp[7]),(void *)(sp[6]),sp[5],sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+9;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XQLength_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XQLength((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XQueryBestCursor_auuuaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  sp[5]=XQueryBestCursor((void *)(sp[5]),sp[4],sp[3],sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XQueryBestSize_anuuuaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=6, farg0=-1;
  sp[6]=XQueryBestSize((void *)(sp[6]),sp[5],sp[4],sp[3],sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+6;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XQueryBestStipple_auuuaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  sp[5]=XQueryBestStipple((void *)(sp[5]),sp[4],sp[3],sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XQueryBestTile_auuuaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  sp[5]=XQueryBestTile((void *)(sp[5]),sp[4],sp[3],sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XQueryColor_aua_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XQueryColor((void *)(sp[2]),sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XQueryColors_auan_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=XQueryColors((void *)(sp[3]),sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XQueryExtension_aaaaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  sp[4]=XQueryExtension((void *)(sp[4]),(void *)(sp[3]),(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XQueryKeymap_aa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XQueryKeymap((void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XQueryPointer_auaaaaaaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=8, farg0=-1;
  sp[8]=XQueryPointer((void *)(sp[8]),sp[7],(void *)(sp[6]),(void *)(sp[5]),(void *)(sp[4]),(void *)(sp[3]),(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+8;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XQueryTextExtents_auanaaaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=7, farg0=-1;
  sp[7]=XQueryTextExtents((void *)(sp[7]),sp[6],(void *)(sp[5]),sp[4],(void *)(sp[3]),(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+7;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XQueryTextExtents16_auanaaaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=7, farg0=-1;
  sp[7]=XQueryTextExtents16((void *)(sp[7]),sp[6],(void *)(sp[5]),sp[4],(void *)(sp[3]),(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+7;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XQueryTree_auaaaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  sp[5]=XQueryTree((void *)(sp[5]),sp[4],(void *)(sp[3]),(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XRaiseWindow_au_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XRaiseWindow((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XReadBitmapFile_auaaaaaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=7, farg0=-1;
  sp[7]=XReadBitmapFile((void *)(sp[7]),sp[6],(void *)(sp[5]),(void *)(sp[4]),(void *)(sp[3]),(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+7;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XReadBitmapFileData_aaaaaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  sp[5]=XReadBitmapFileData((void *)(sp[5]),(void *)(sp[4]),(void *)(sp[3]),(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XRebindKeysym_auanan_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  sp[5]=XRebindKeysym((void *)(sp[5]),sp[4],(void *)(sp[3]),sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XRecolorCursor_auaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=XRecolorCursor((void *)(sp[3]),sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XRefreshKeyboardMapping_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XRefreshKeyboardMapping((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XRemoveFromSaveSet_au_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XRemoveFromSaveSet((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XRemoveHost_aa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XRemoveHost((void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XRemoveHosts_aan_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XRemoveHosts((void *)(sp[2]),(void *)(sp[1]),sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XReparentWindow_auunn_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  sp[4]=XReparentWindow((void *)(sp[4]),sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XResetScreenSaver_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XResetScreenSaver((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XResizeWindow_auuu_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=XResizeWindow((void *)(sp[3]),sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XRestackWindows_aan_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XRestackWindows((void *)(sp[2]),(void *)(sp[1]),sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XRotateBuffers_an_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XRotateBuffers((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XRotateWindowProperties_auann_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  sp[4]=XRotateWindowProperties((void *)(sp[4]),sp[3],(void *)(sp[2]),sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XScreenCount_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XScreenCount((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSelectInput_aun_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XSelectInput((void *)(sp[2]),sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSendEvent_aunna_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  sp[4]=XSendEvent((void *)(sp[4]),sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetAccessControl_an_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XSetAccessControl((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetArcMode_aan_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XSetArcMode((void *)(sp[2]),(void *)(sp[1]),sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetBackground_aau_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XSetBackground((void *)(sp[2]),(void *)(sp[1]),sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetClipMask_aau_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XSetClipMask((void *)(sp[2]),(void *)(sp[1]),sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetClipOrigin_aann_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=XSetClipOrigin((void *)(sp[3]),(void *)(sp[2]),sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetClipRectangles_aannann_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=6, farg0=-1;
  sp[6]=XSetClipRectangles((void *)(sp[6]),(void *)(sp[5]),sp[4],sp[3],(void *)(sp[2]),sp[1],sp[0]);
  x.sp = sp+6;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetCloseDownMode_an_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XSetCloseDownMode((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetCommand_auan_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=XSetCommand((void *)(sp[3]),sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetDashes_aanan_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  sp[4]=XSetDashes((void *)(sp[4]),(void *)(sp[3]),sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetFillRule_aan_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XSetFillRule((void *)(sp[2]),(void *)(sp[1]),sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetFillStyle_aan_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XSetFillStyle((void *)(sp[2]),(void *)(sp[1]),sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetFont_aau_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XSetFont((void *)(sp[2]),(void *)(sp[1]),sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetFontPath_aan_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XSetFontPath((void *)(sp[2]),(void *)(sp[1]),sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetForeground_aau_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XSetForeground((void *)(sp[2]),(void *)(sp[1]),sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetFunction_aan_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XSetFunction((void *)(sp[2]),(void *)(sp[1]),sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetGraphicsExposures_aan_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XSetGraphicsExposures((void *)(sp[2]),(void *)(sp[1]),sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetIconName_aua_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XSetIconName((void *)(sp[2]),sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetInputFocus_aunu_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=XSetInputFocus((void *)(sp[3]),sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetLineAttributes_aaunnn_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  sp[5]=XSetLineAttributes((void *)(sp[5]),(void *)(sp[4]),sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetModifierMapping_aa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XSetModifierMapping((void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetPlaneMask_aau_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XSetPlaneMask((void *)(sp[2]),(void *)(sp[1]),sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetPointerMapping_aan_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XSetPointerMapping((void *)(sp[2]),(void *)(sp[1]),sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetScreenSaver_annnn_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  sp[4]=XSetScreenSaver((void *)(sp[4]),sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetSelectionOwner_auuu_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=XSetSelectionOwner((void *)(sp[3]),sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetState_aauunu_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  sp[5]=XSetState((void *)(sp[5]),(void *)(sp[4]),sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetStipple_aau_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XSetStipple((void *)(sp[2]),(void *)(sp[1]),sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetSubwindowMode_aan_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XSetSubwindowMode((void *)(sp[2]),(void *)(sp[1]),sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetTSOrigin_aann_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=XSetTSOrigin((void *)(sp[3]),(void *)(sp[2]),sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetTile_aau_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XSetTile((void *)(sp[2]),(void *)(sp[1]),sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetWindowBackground_auu_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XSetWindowBackground((void *)(sp[2]),sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetWindowBackgroundPixmap_auu_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XSetWindowBackgroundPixmap((void *)(sp[2]),sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetWindowBorder_auu_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XSetWindowBorder((void *)(sp[2]),sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetWindowBorderPixmap_auu_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XSetWindowBorderPixmap((void *)(sp[2]),sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetWindowBorderWidth_auu_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XSetWindowBorderWidth((void *)(sp[2]),sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetWindowColormap_auu_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XSetWindowColormap((void *)(sp[2]),sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XStoreBuffer_aann_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=XStoreBuffer((void *)(sp[3]),(void *)(sp[2]),sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XStoreBytes_aan_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XStoreBytes((void *)(sp[2]),(void *)(sp[1]),sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XStoreColor_aua_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XStoreColor((void *)(sp[2]),sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XStoreColors_auan_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=XStoreColors((void *)(sp[3]),sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XStoreName_aua_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XStoreName((void *)(sp[2]),sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XStoreNamedColor_auaun_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  sp[4]=XStoreNamedColor((void *)(sp[4]),sp[3],(void *)(sp[2]),sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSync_an_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XSync((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XTextExtents_aanaaaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=6, farg0=-1;
  sp[6]=XTextExtents((void *)(sp[6]),(void *)(sp[5]),sp[4],(void *)(sp[3]),(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+6;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XTextExtents16_aanaaaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=6, farg0=-1;
  sp[6]=XTextExtents16((void *)(sp[6]),(void *)(sp[5]),sp[4],(void *)(sp[3]),(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+6;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XTextWidth_aan_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XTextWidth((void *)(sp[2]),(void *)(sp[1]),sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XTextWidth16_aan_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XTextWidth16((void *)(sp[2]),(void *)(sp[1]),sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XTranslateCoordinates_auunnaaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=7, farg0=-1;
  sp[7]=XTranslateCoordinates((void *)(sp[7]),sp[6],sp[5],sp[4],sp[3],(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+7;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XUndefineCursor_au_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XUndefineCursor((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XUngrabButton_auuu_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=XUngrabButton((void *)(sp[3]),sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XUngrabKey_anuu_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=XUngrabKey((void *)(sp[3]),sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XUngrabKeyboard_au_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XUngrabKeyboard((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XUngrabPointer_au_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XUngrabPointer((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XUngrabServer_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XUngrabServer((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XUninstallColormap_au_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XUninstallColormap((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XUnloadFont_au_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XUnloadFont((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XUnmapSubwindows_au_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XUnmapSubwindows((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XUnmapWindow_au_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XUnmapWindow((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XVendorRelease_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XVendorRelease((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XWarpPointer_auunnuunn_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=8, farg0=-1;
  sp[8]=XWarpPointer((void *)(sp[8]),sp[7],sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+8;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XWidthMMOfScreen_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XWidthMMOfScreen((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XWidthOfScreen_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XWidthOfScreen((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XWindowEvent_auna_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=XWindowEvent((void *)(sp[3]),sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XWriteBitmapFile_aauuunn_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=6, farg0=-1;
  sp[6]=XWriteBitmapFile((void *)(sp[6]),(void *)(sp[5]),sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+6;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSupportsLocale__n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  sp[-1]=XSupportsLocale();
  x.sp = sp+-1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetLocaleModifiers_a_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=(Cell)XSetLocaleModifiers((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XOpenOM_aaaa_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=(Cell)XOpenOM((void *)(sp[3]),(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XCloseOM_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XCloseOM((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetOMValues_aaaa_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=(Cell)XSetOMValues((void *)(sp[3]),(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XGetOMValues_aaaa_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=(Cell)XGetOMValues((void *)(sp[3]),(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XDisplayOfOM_a_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=(Cell)XDisplayOfOM((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XLocaleOfOM_a_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=(Cell)XLocaleOfOM((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XCreateOC_aaaa_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=(Cell)XCreateOC((void *)(sp[3]),(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XDestroyOC_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  XDestroyOC((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XOMOfOC_a_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=(Cell)XOMOfOC((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetOCValues_aaaa_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=(Cell)XSetOCValues((void *)(sp[3]),(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XGetOCValues_aaaa_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=(Cell)XGetOCValues((void *)(sp[3]),(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XCreateFontSet_aaaaa_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  sp[4]=(Cell)XCreateFontSet((void *)(sp[4]),(void *)(sp[3]),(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XFreeFontSet_aa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  XFreeFontSet((void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XFontsOfFontSet_aaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XFontsOfFontSet((void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XBaseFontNameListOfFontSet_a_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=(Cell)XBaseFontNameListOfFontSet((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XLocaleOfFontSet_a_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=(Cell)XLocaleOfFontSet((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XContextDependentDrawing_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XContextDependentDrawing((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XDirectionalDependentDrawing_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XDirectionalDependentDrawing((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XContextualDrawing_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XContextualDrawing((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XExtentsOfFontSet_a_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=(Cell)XExtentsOfFontSet((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XmbTextEscapement_aan_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XmbTextEscapement((void *)(sp[2]),(void *)(sp[1]),sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XwcTextEscapement_aan_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XwcTextEscapement((void *)(sp[2]),(void *)(sp[1]),sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_Xutf8TextEscapement_aan_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=Xutf8TextEscapement((void *)(sp[2]),(void *)(sp[1]),sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XmbTextExtents_aanaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  sp[4]=XmbTextExtents((void *)(sp[4]),(void *)(sp[3]),sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XwcTextExtents_aanaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  sp[4]=XwcTextExtents((void *)(sp[4]),(void *)(sp[3]),sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfx_LTX_gforth_c_Xutf8TextExtents_aanaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  sp[4]=Xutf8TextExtents((void *)(sp[4]),(void *)(sp[3]),sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XmbTextPerCharExtents_aanaanaaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=8, farg0=-1;
  sp[8]=XmbTextPerCharExtents((void *)(sp[8]),(void *)(sp[7]),sp[6],(void *)(sp[5]),(void *)(sp[4]),sp[3],(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+8;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XwcTextPerCharExtents_aanaanaaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=8, farg0=-1;
  sp[8]=XwcTextPerCharExtents((void *)(sp[8]),(void *)(sp[7]),sp[6],(void *)(sp[5]),(void *)(sp[4]),sp[3],(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+8;
  return x;
}
ptrpair libgfx_LTX_gforth_c_Xutf8TextPerCharExtents_aanaanaaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=8, farg0=-1;
  sp[8]=Xutf8TextPerCharExtents((void *)(sp[8]),(void *)(sp[7]),sp[6],(void *)(sp[5]),(void *)(sp[4]),sp[3],(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+8;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XmbDrawText_auannan_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=6, farg0=-1;
  XmbDrawText((void *)(sp[6]),sp[5],(void *)(sp[4]),sp[3],sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+7;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XwcDrawText_auannan_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=6, farg0=-1;
  XwcDrawText((void *)(sp[6]),sp[5],(void *)(sp[4]),sp[3],sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+7;
  return x;
}
ptrpair libgfx_LTX_gforth_c_Xutf8DrawText_auannan_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=6, farg0=-1;
  Xutf8DrawText((void *)(sp[6]),sp[5],(void *)(sp[4]),sp[3],sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+7;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XmbDrawString_auaannan_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=7, farg0=-1;
  XmbDrawString((void *)(sp[7]),sp[6],(void *)(sp[5]),(void *)(sp[4]),sp[3],sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+8;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XwcDrawString_auaannan_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=7, farg0=-1;
  XwcDrawString((void *)(sp[7]),sp[6],(void *)(sp[5]),(void *)(sp[4]),sp[3],sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+8;
  return x;
}
ptrpair libgfx_LTX_gforth_c_Xutf8DrawString_auaannan_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=7, farg0=-1;
  Xutf8DrawString((void *)(sp[7]),sp[6],(void *)(sp[5]),(void *)(sp[4]),sp[3],sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+8;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XmbDrawImageString_auaannan_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=7, farg0=-1;
  XmbDrawImageString((void *)(sp[7]),sp[6],(void *)(sp[5]),(void *)(sp[4]),sp[3],sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+8;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XwcDrawImageString_auaannan_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=7, farg0=-1;
  XwcDrawImageString((void *)(sp[7]),sp[6],(void *)(sp[5]),(void *)(sp[4]),sp[3],sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+8;
  return x;
}
ptrpair libgfx_LTX_gforth_c_Xutf8DrawImageString_auaannan_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=7, farg0=-1;
  Xutf8DrawImageString((void *)(sp[7]),sp[6],(void *)(sp[5]),(void *)(sp[4]),sp[3],sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+8;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XOpenIM_aaaa_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=(Cell)XOpenIM((void *)(sp[3]),(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XCloseIM_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XCloseIM((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XGetIMValues_aaaa_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=(Cell)XGetIMValues((void *)(sp[3]),(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetIMValues_aaaa_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=(Cell)XSetIMValues((void *)(sp[3]),(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XDisplayOfIM_a_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=(Cell)XDisplayOfIM((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XLocaleOfIM_a_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=(Cell)XLocaleOfIM((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XCreateIC_aaaa_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=(Cell)XCreateIC((void *)(sp[3]),(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XDestroyIC_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  XDestroyIC((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetICFocus_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  XSetICFocus((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XUnsetICFocus_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  XUnsetICFocus((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XwcResetIC_a_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=(Cell)XwcResetIC((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XmbResetIC_a_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=(Cell)XmbResetIC((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_Xutf8ResetIC_a_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=(Cell)Xutf8ResetIC((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetICValues_aaaa_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=(Cell)XSetICValues((void *)(sp[3]),(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XGetICValues_aaaa_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=(Cell)XGetICValues((void *)(sp[3]),(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XIMOfIC_a_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=(Cell)XIMOfIC((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XFilterEvent_au_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XFilterEvent((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XmbLookupString_aaanaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  sp[5]=XmbLookupString((void *)(sp[5]),(void *)(sp[4]),(void *)(sp[3]),sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XwcLookupString_aaanaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  sp[5]=XwcLookupString((void *)(sp[5]),(void *)(sp[4]),(void *)(sp[3]),sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfx_LTX_gforth_c_Xutf8LookupString_aaanaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  sp[5]=Xutf8LookupString((void *)(sp[5]),(void *)(sp[4]),(void *)(sp[3]),sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XVaCreateNestedList_naaa_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=(Cell)XVaCreateNestedList(sp[3],(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XRegisterIMInstantiateCallback_aaaaaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  sp[5]=XRegisterIMInstantiateCallback((void *)(sp[5]),(void *)(sp[4]),(void *)(sp[3]),(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XUnregisterIMInstantiateCallback_aaaaaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  sp[5]=XUnregisterIMInstantiateCallback((void *)(sp[5]),(void *)(sp[4]),(void *)(sp[3]),(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XInternalConnectionNumbers_aaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XInternalConnectionNumbers((void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XProcessInternalConnection_an_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  XProcessInternalConnection((void *)(sp[1]),sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XAddConnectionWatch_aaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XAddConnectionWatch((void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XRemoveConnectionWatch_aaa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  XRemoveConnectionWatch((void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetAuthorization_anan_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  XSetAuthorization((void *)(sp[3]),sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfx_LTX_gforth_c__Xmbtowc_aan_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=_Xmbtowc((void *)(sp[2]),(void *)(sp[1]),sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c__Xwctomb_an_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=_Xwctomb((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XGetEventData_aa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XGetEventData((void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XFreeEventData_aa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  XFreeEventData((void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XAllocClassHint__a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  sp[-1]=(Cell)XAllocClassHint();
  x.sp = sp+-1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XAllocIconSize__a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  sp[-1]=(Cell)XAllocIconSize();
  x.sp = sp+-1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XAllocSizeHints__a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  sp[-1]=(Cell)XAllocSizeHints();
  x.sp = sp+-1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XAllocStandardColormap__a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  sp[-1]=(Cell)XAllocStandardColormap();
  x.sp = sp+-1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XAllocWMHints__a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  sp[-1]=(Cell)XAllocWMHints();
  x.sp = sp+-1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XClipBox_aa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XClipBox((void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XCreateRegion__a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  sp[-1]=(Cell)XCreateRegion();
  x.sp = sp+-1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XDefaultString__a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  sp[-1]=(Cell)XDefaultString();
  x.sp = sp+-1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XDeleteContext_aun_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XDeleteContext((void *)(sp[2]),sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XDestroyRegion_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XDestroyRegion((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XEmptyRegion_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=XEmptyRegion((void *)(sp[0]));
  return x;
}
ptrpair libgfx_LTX_gforth_c_XEqualRegion_aa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=XEqualRegion((void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XFindContext_auna_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=XFindContext((void *)(sp[3]),sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XGetClassHint_aua_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XGetClassHint((void *)(sp[2]),sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XGetIconSizes_auaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=XGetIconSizes((void *)(sp[3]),sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XGetNormalHints_aua_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XGetNormalHints((void *)(sp[2]),sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XGetRGBColormaps_auaau_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  sp[4]=XGetRGBColormaps((void *)(sp[4]),sp[3],(void *)(sp[2]),(void *)(sp[1]),sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XGetSizeHints_auau_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=XGetSizeHints((void *)(sp[3]),sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XGetStandardColormap_auau_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=XGetStandardColormap((void *)(sp[3]),sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XGetTextProperty_auau_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=XGetTextProperty((void *)(sp[3]),sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XGetVisualInfo_anaa_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=(Cell)XGetVisualInfo((void *)(sp[3]),sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XGetWMClientMachine_aua_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XGetWMClientMachine((void *)(sp[2]),sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XGetWMHints_au_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=(Cell)XGetWMHints((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XGetWMIconName_aua_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XGetWMIconName((void *)(sp[2]),sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XGetWMName_aua_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XGetWMName((void *)(sp[2]),sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XGetWMNormalHints_auaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=XGetWMNormalHints((void *)(sp[3]),sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XGetWMSizeHints_auaau_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  sp[4]=XGetWMSizeHints((void *)(sp[4]),sp[3],(void *)(sp[2]),(void *)(sp[1]),sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XGetZoomHints_aua_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XGetZoomHints((void *)(sp[2]),sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XIntersectRegion_aaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XIntersectRegion((void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XConvertCase_uaa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  XConvertCase(sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XLookupString_aanaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  sp[4]=XLookupString((void *)(sp[4]),(void *)(sp[3]),sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XMatchVisualInfo_annna_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  sp[4]=XMatchVisualInfo((void *)(sp[4]),sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XOffsetRegion_ann_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XOffsetRegion((void *)(sp[2]),sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XPointInRegion_ann_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XPointInRegion((void *)(sp[2]),sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XPolygonRegion_ann_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=(Cell)XPolygonRegion((void *)(sp[2]),sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XRectInRegion_annuu_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  sp[4]=XRectInRegion((void *)(sp[4]),sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSaveContext_auna_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=XSaveContext((void *)(sp[3]),sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetClassHint_aua_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XSetClassHint((void *)(sp[2]),sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetIconSizes_auan_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=XSetIconSizes((void *)(sp[3]),sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetNormalHints_aua_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XSetNormalHints((void *)(sp[2]),sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetRGBColormaps_auanu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  XSetRGBColormaps((void *)(sp[4]),sp[3],(void *)(sp[2]),sp[1],sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetSizeHints_auau_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=XSetSizeHints((void *)(sp[3]),sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetStandardProperties_auaauana_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=7, farg0=-1;
  sp[7]=XSetStandardProperties((void *)(sp[7]),sp[6],(void *)(sp[5]),(void *)(sp[4]),sp[3],(void *)(sp[2]),sp[1],(void *)(sp[0]));
  x.sp = sp+7;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetTextProperty_auau_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  XSetTextProperty((void *)(sp[3]),sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetWMClientMachine_aua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  XSetWMClientMachine((void *)(sp[2]),sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetWMHints_aua_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XSetWMHints((void *)(sp[2]),sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetWMIconName_aua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  XSetWMIconName((void *)(sp[2]),sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetWMName_aua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  XSetWMName((void *)(sp[2]),sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetWMNormalHints_aua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  XSetWMNormalHints((void *)(sp[2]),sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetWMProperties_auaaanaaa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=8, farg0=-1;
  XSetWMProperties((void *)(sp[8]),sp[7],(void *)(sp[6]),(void *)(sp[5]),(void *)(sp[4]),sp[3],(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+9;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XmbSetWMProperties_auaaanaaa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=8, farg0=-1;
  XmbSetWMProperties((void *)(sp[8]),sp[7],(void *)(sp[6]),(void *)(sp[5]),(void *)(sp[4]),sp[3],(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+9;
  return x;
}
ptrpair libgfx_LTX_gforth_c_Xutf8SetWMProperties_auaaanaaa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=8, farg0=-1;
  Xutf8SetWMProperties((void *)(sp[8]),sp[7],(void *)(sp[6]),(void *)(sp[5]),(void *)(sp[4]),sp[3],(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+9;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetWMSizeHints_auau_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  XSetWMSizeHints((void *)(sp[3]),sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetRegion_aaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XSetRegion((void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetStandardColormap_auau_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  XSetStandardColormap((void *)(sp[3]),sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetZoomHints_aua_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XSetZoomHints((void *)(sp[2]),sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XShrinkRegion_ann_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XShrinkRegion((void *)(sp[2]),sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XStringListToTextProperty_ana_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XStringListToTextProperty((void *)(sp[2]),sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSubtractRegion_aaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XSubtractRegion((void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XmbTextListToTextProperty_aanna_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  sp[4]=XmbTextListToTextProperty((void *)(sp[4]),(void *)(sp[3]),sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XwcTextListToTextProperty_aanna_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  sp[4]=XwcTextListToTextProperty((void *)(sp[4]),(void *)(sp[3]),sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfx_LTX_gforth_c_Xutf8TextListToTextProperty_aanna_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  sp[4]=Xutf8TextListToTextProperty((void *)(sp[4]),(void *)(sp[3]),sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XwcFreeStringList_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  XwcFreeStringList((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XTextPropertyToStringList_aaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XTextPropertyToStringList((void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XmbTextPropertyToTextList_aaaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=XmbTextPropertyToTextList((void *)(sp[3]),(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XwcTextPropertyToTextList_aaaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=XwcTextPropertyToTextList((void *)(sp[3]),(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_Xutf8TextPropertyToTextList_aaaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=Xutf8TextPropertyToTextList((void *)(sp[3]),(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XUnionRectWithRegion_aaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XUnionRectWithRegion((void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XUnionRegion_aaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XUnionRegion((void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XWMGeometry_anaauaaaaaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=10, farg0=-1;
  sp[10]=XWMGeometry((void *)(sp[10]),sp[9],(void *)(sp[8]),(void *)(sp[7]),sp[6],(void *)(sp[5]),(void *)(sp[4]),(void *)(sp[3]),(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+10;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XXorRegion_aaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=XXorRegion((void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XVaCreateNestedList_naaaaa_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  sp[5]=(Cell)XVaCreateNestedList(sp[5],(void *)(sp[4]),(void *)(sp[3]),(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XCreateIC_aaaaaa_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  sp[5]=(Cell)XCreateIC((void *)(sp[5]),(void *)(sp[4]),(void *)(sp[3]),(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XCreateIC_aaaaaaaa_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=7, farg0=-1;
  sp[7]=(Cell)XCreateIC((void *)(sp[7]),(void *)(sp[6]),(void *)(sp[5]),(void *)(sp[4]),(void *)(sp[3]),(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+7;
  return x;
}
ptrpair libgfx_LTX_gforth_c_XSetICValues_aaaaaa_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  sp[5]=(Cell)XSetICValues((void *)(sp[5]),(void *)(sp[4]),(void *)(sp[3]),(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
hash_128 gflibcc_hash_x = "\xEC\xD1\x73\xD4\x0D\x11\x87\x28\x2A\xE4\xAF\x97\x87\xE4\x45\x7B";
